/************************************************************************
 *   IRC - Internet Relay Chat, admin/m_dump.c
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Computing Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers. 
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "client.h"
#include "msg.h"
#include "handlers.h"
#include "database/database.h"
#include "varparse.h"

int m_dump(struct Client *, struct Client *, int, char **);

struct Message dump_msgtab = {
  "DUMP", 0, 0, 0, MFLG_SLOW, 0,
  {m_unregistered, m_dump, m_dump},
  NULL, NULL
};

var_handler_func m_dump_ccr_allow, m_dump_ccr_deny;

static struct variable_tier dump_ccr_parse_tree[] = {
  {"ALLOW", 0, NULL, m_dump_ccr_allow},
  {"DENY",  0, NULL, m_dump_ccr_deny},
  {NULL, 0, NULL, NULL}
};

static struct variable_tier dump_parse_tree[] = {
  {"CCR", 0, dump_ccr_parse_tree, NULL},
  {NULL, 0, NULL, NULL}
};

int
m_dump(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  return variable_parse(cptr, sptr, parc, parv, dump_parse_tree, "DUMP");
}

int
m_dump_ccr_allow(struct Client *cptr, struct Client *sptr, int parc, char *parv[], char *varparv[])
{
  char *mask;
  if (parc > 2)
    mask = parv[2];
  else
    mask = "*";

  if (parc > 3)
    search_allow_ccr(sptr, mask, 1);
  else
    search_allow_ccr(sptr, mask, 0);

  return 0;
}

int
m_dump_ccr_deny(struct Client *cptr, struct Client *sptr, int parc, char *parv[], char *varparv[])
{
  char *mask;
  if (parc > 2)
    mask = parv[2];
  else
    mask = "*";

  if (parc > 3)
    search_deny_ccr(sptr, mask, 1);
  else
    search_deny_ccr(sptr, mask, 0);

  return 0;
}
